<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

defined('_JEXEC') or die;

use FOF40\Date\Date;

/** @var Akeeba\TicketSystem\Admin\View\ControlPanel\Html $this */

$container = $this->getContainer();
$template = $container->template;

$this->container->platform->addScriptOptions('ats.ControlPanel.needsDownloadID', (bool) $this->needsdlid);
?>
{{-- Joomla 4 upgrade prompt --}}
@if(version_compare(JVERSION, '3.999.999', 'gt'))
    <div class="akeeba-block--warning--large">
        <h1>🚨 🚨 🚨 Please upgrade to Akeeba Ticket System 5 🚨 🚨 🚨</h1>
        <p style="font-size: 1.5rem; margin: 1rem 0 0">
            You are currently using Akeeba Ticket System 4. This version was only made minimally compatible with Joomla 4 to allow you to upgrade from Joomla 3 to Joomla 4 without losing your settings. We will not provide support for Akeeba Ticket System 4 running on Joomla 4.0 and later.
        </p>
        <p style="font-size: 1.5rem; margin: 1rem 0 0">
            You need to download and install Akeeba Ticket System 5, our Joomla 4 native version of Akeeba Ticket System. It is fully supported for use on Joomla 4.
        </p>
        <p style="font-size: 1.5rem; margin: 1rem 0 0">
            The update should show up on your site's extensions update page. It may take a day or two as Joomla is caching the updates. If you do not see the update, you can download Akeeba Ticket System 5 manually and install it over Akeeba Ticket System 4 <em>without</em> uninstalling your existing copy of Akeeba Ticket System.
        </p>
        <p>
            <a href="https://www.akeeba.com/download.html" class="akeeba-btn--green--big--block" style="font-size: 1.5rem; margin: 2rem 0">
                <span class="akion akion-ios-download" aria-hidden="true"></span>
                Download Akeeba Ticket System 5 now
            </a>
        </p>
    </div>
@endif

{{-- Joomla 3 End of Life notice --}}
@if(time() > 1660683600)
    <details class="akeeba-block--warning">
        <summary>Joomla 3 is approaching its End of Life</summary>
        <p>
            Joomla 3 will become End of Life on August 17th, 2023. We will no longer provide any support or software updates for Joomla 3 after it becomes End of Life.
        </p>
        <p>
            Please upgrade your site to the latest Joomla version (Joomla 4 at the time of this writing) as soon as humanly possible. Afterward, please update Akeeba Ticket System to the latest released version. The longer you delay the less likely is that there will be an upgrade path for your site.
        </p>
    </details>
@elseif(time() > 1692219600)
    <details class="akeeba-block--info">
        <summary>Joomla 3 is End of Life</summary>
        <p>
            We only provide security updates until August 17th, 2024 for our Joomla 3 software. You can also purchase extended, but limited, support for our software running on Joomla 3 until that date. The limited support does not cover bug fixes, new features, or addressing compatibility issues with third party services and new web server and web browser versions.
        </p>
        <p>
            Please upgrade your site to the latest Joomla version as soon as humanly possible and update Akeeba Ticket System to the latest released version. The longer you delay the less likely is that there will be an upgrade path for your site.
        </p>
    </details>
@endif

@include('admin:com_ats/ControlPanel/needs_menu_item')
@include('admin:com_ats/ControlPanel/stuck_updates')
@include('admin:com_ats/ControlPanel/needs_dlid')

{{-- Old PHP version reminder --}}
@include('admin:com_ats/Common/phpversion_warning', [
    'softwareName'  => 'Akeeba Ticket System',
    'minPHPVersion' => '7.2.0',
])

<div class="akeeba-container--50-50">
    <div>
        <div class="akeeba-panel--info">
            <header class="akeeba-block-header">
                <h3>@lang('COM_ATS_CPANEL_TICKETS')</h3>
            </header>

            @include('admin:com_ats/ControlPanel/ticketgraph')
        </div>

        <div class="akeeba-panel--info">
            <header class="akeeba-block-header">
                <h3>@lang('COM_ATS_CPANEL_SPAREDTICKTS')</h3>
            </header>

            @include('admin:com_ats/ControlPanel/spared')
        </div>
    </div>

    <div>
        <div class="akeeba-panel--info">
            <header class="akeeba-block-header">
                <h3>@lang('COM_ATS_CPANEL_STATS')</h3>
            </header>

            @include('admin:com_ats/ControlPanel/ticketstats')
        </div>
    </div>
</div>
<div class="akeeba-panel--info">
    <p>
        <strong>
            Akeeba Ticket System {{ ATS_VERSION }}
        </strong>

        <br />
        <span style="font-size: x-small">
                Copyright &copy;2010&ndash;{{ $this->getContainer()->platform->getDate(ATS_DATE)->format('Y') }}
                Nicholas K. Dionysopoulos / Akeeba Ltd
            </span>
        <br />

        <span style="font-size: x-small">
                Akeeba Ticket System is Free software released under the
                <a href="http://www.gnu.org/licenses/gpl.html">GNU General Public License,</a>
                version 3 of the license or &ndash;at your option&ndash; any later version
                published by the Free Software Foundation.
            </span>
    </p>
</div>

{{ $this->statsIframe or '' }}

<div style="clear: both;"></div>